==> goods-center-api-1.9.7-20170223.113330-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemExtraDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import java.io.Serializable;
import java.util.Date;

/**
 * item 扩展表
 */
public class ItemExtraDto implements Serializable {
    private static final long serialVersionUID = -26122562121559924L;

    private Long   id;
    private Long   itemId;
    private String name4Admin;
    private Date   gmtCreate;
    private Date   gmtModified;
    private String usePrompt;
    private String btnText;
    
    public String getUsePrompt() {
        return usePrompt;
    }

    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getName4Admin() {
        return name4Admin;
    }

    public void setName4Admin(String name4Admin) {
        this.name4Admin = name4Admin;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> goods-center-api-2.4.10-20180610.034104-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemExtraDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import cn.com.duiba.goods.center.api.remoteservice.dto.BaseImgDto;

import java.io.Serializable;
import java.util.Date;

/**
 * item 扩展表
 */
public class ItemExtraDto extends BaseImgDto implements Serializable {
    private static final long serialVersionUID = -26122562121559924L;

    private Long   id;
    private Long   itemId;
    private String name4Admin;
    private Date   gmtCreate;
    private Date   gmtModified;
    private String usePrompt;
    private String btnText;
    private String ownerAppIds;
    /**
     * 随机奖金区间,用于集卡商品
     * 保存格式 a,b
     * 0 < a <= b
     * a,b是以人民币分为单位的整数
     * */
    private String bonusArea;


    public String getOwnerAppIds() {
        return ownerAppIds;
    }

    public void setOwnerAppIds(String ownerAppIds) {
        this.ownerAppIds = ownerAppIds;
    }

    public String getUsePrompt() {
        return usePrompt;
    }

    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    public String getBtnText() {
        return btnText;
    }

    public void setBtnText(String btnText) {
        this.btnText = btnText;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getName4Admin() {
        return name4Admin;
    }

    public void setName4Admin(String name4Admin) {
        this.name4Admin = name4Admin;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getBonusArea() {
        return bonusArea;
    }

    public void setBonusArea(String bonusArea) {
        this.bonusArea = bonusArea;
    }
}
